@@ -88,6 +88,10 @@ func RegistryCreate(ctx context.Context, runtime runtimes.Runtime, reg *k3d.Regi
 		}
 	}
 
+	if reg.Options.DeleteEnabled {
+		registryNode.Env = append(registryNode.Env, "REGISTRY_STORAGE_DELETE_ENABLED=true")
+	}
+
 	if len(reg.Volumes) > 0 {
 		registryNode.Volumes = reg.Volumes
 	}
@@ -359,7 +363,7 @@ func RegistryGenerateLocalRegistryHostingConfigMapYAML(ctx context.Context, runt
 	return cmYaml, nil
 }
 
-// RegistryMergeConfig merges a source registry config into an existing dest registry cofnig
+// RegistryMergeConfig merges a source registry config into an existing dest registry config
 func RegistryMergeConfig(ctx context.Context, dest, src *wharfie.Registry) error {
 	if err := mergo.MergeWithOverwrite(dest, src); err != nil {
 		return fmt.Errorf("failed to merge registry configs: %w", err)
