@@ -1,5 +1,5 @@
 /*
-Copyright © 2020-2022 The k3d Author(s)
+Copyright © 2020-2023 The k3d Author(s)
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -33,7 +33,7 @@ type Channel struct {
 
 type ChannelServerResponse struct {
 	Channels []struct {
-		Channel `json:",squash"`
+		Channel `mapstructure:",squash"`
 	} `json:"data"`
 }
 
